@@ -1,12 +1,11 @@
 use super::*;
 
-
 impl TailwindInstance for TailwindPadding {
     fn id(&self) -> String {
         todo!()
     }
-    fn attributes(&self) -> Vec<String> {
-        todo!()
+    fn attributes(&self) -> BTreeSet<CssAttribute> {
+        css_attributes! {}
     }
 }
 
@@ -14,7 +13,7 @@ impl TailwindInstance for TailwindMargin {
     fn id(&self) -> String {
         todo!()
     }
-    fn attributes(&self) -> Vec<String> {
-        todo!()
+    fn attributes(&self) -> BTreeSet<CssAttribute> {
+        css_attributes! {}
     }
 }
