@@ -8,10 +8,9 @@ use nom::{
 
 impl TailwindBorderCollapse {
     pub fn parser<'a>() -> impl FnMut(&'a str) -> ParsedList<'a> {
-        move |input| as_list(alt((
-            Self::parser_kind("collapse", Self::Collapse),
-            Self::parser_kind("separate", Self::Collapse),
-        ))(input))
+        move |input| {
+            as_list(alt((Self::parser_kind("collapse", Self::Collapse), Self::parser_kind("separate", Self::Collapse)))(input))
+        }
     }
     pub fn parser_kind<'a>(kind: &'static str, item: Self) -> impl Fn(&'a str) -> ParsedItem {
         move |input| match tuple((
@@ -29,10 +28,7 @@ impl TailwindBorderCollapse {
 
 impl TailwindTableLayout {
     pub fn parser<'a>() -> impl FnMut(&'a str) -> ParsedList<'a> {
-        move |input| as_list(alt((
-            Self::parser_kind("auto", Self::Auto),
-            Self::parser_kind("fixed", Self::Fixed),
-        ))(input))
+        move |input| as_list(alt((Self::parser_kind("auto", Self::Auto), Self::parser_kind("fixed", Self::Fixed)))(input))
     }
     pub fn parser_kind<'a>(kind: &'static str, item: Self) -> impl Fn(&'a str) -> ParsedItem {
         move |input| match tuple((
@@ -47,4 +43,3 @@ impl TailwindTableLayout {
         }
     }
 }
-
