@@ -1,7 +1,6 @@
 mod systems;
 
-use tailwind_css::TailwindBuilder;
-use tailwind_css::TailwindObject;
+use tailwind_css::{TailwindBuilder, TailwindObject};
 
 #[test]
 fn ready() {
@@ -10,10 +9,7 @@ fn ready() {
 
 pub fn build_target(id: &str, input: &str, inline_target: &str, bundle_target: &str) {
     let mut tailwind = TailwindBuilder::default();
-    let inline = TailwindObject {
-        selector: id.to_string(),
-        attributes: tailwind.inline(input)
-    }.to_string();
+    let inline = TailwindObject { selector: id.to_string(), attributes: tailwind.inline(input) }.to_string();
     tailwind.trace(input);
     let bundle = tailwind.bundle().unwrap();
     assert_eq!(inline, inline_target);
